import * as React from 'react';

import {
  Icon,
  Step,
  Button,
  Table,
  Radio,
  Form,
  Container,
  Checkbox,
} from 'semantic-ui-react';
import {
  Grid,
  Image,
  Label,
  Segment,
  Dropdown,
  Input,
  List,
  Accordion,
  Loader,
  DropdownItemProps, DropdownProps,
} from 'semantic-ui-react';


import MetaCrawler from '@overflow/meta/api/model/MetaCrawler';
import Infra from '@overflow/infra/api/model/Infra';
import Domain from '@overflow/domain/api/model/Domain';

import Page from '@overflow/commons/api/model/Page';
import SensorRegistInfo from '../../api/model/SensorRegistInfo';

import PageParams from '@overflow/commons/api/model/PageParams';


export interface StateProps {
  infraList?: Page;
  infra?: Infra;
  infraId?: number;
  setSensor?(data: SensorRegistInfo): void;
  getSensor?(): SensorRegistInfo;
  stepNext?(): void;
}

export interface DispatchProps {

  onReadAllTargetByDomain?(domain: Domain, pageParams: PageParams): void;
  onReadInfra?(infraId: number): void;
}

export type Props = StateProps & DispatchProps;

export interface State {

}



export class SensorConfigTargetSelect extends React.Component<Props, State> {

  private selectOptions: Array<DropdownItemProps>;

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
    };
  }

  public componentWillMount(): void {
    if (this.props.infraId === undefined) {
      const pageParams: PageParams = {
        pageNo: '0',
        countPerPage: '999',
        sortCol: 'id',
        sortDirection: 'descending',
      };
      this.props.onReadAllTargetByDomain({ id: 1 }, pageParams);
    } else {
      this.props.onReadInfra(this.props.infraId);
    }
  }

  public convertInfraList(): void {

    if (this.props.infraList === undefined) {
      return null;
    }

    let selectionOptions: Array<DropdownItemProps> = new Array;

    for (let infra of this.props.infraList.content) {

      selectionOptions.push(this.createOption(infra));

    }
    this.selectOptions = selectionOptions;
  }

  public convertInfra(): void {
    if (this.props.infra === undefined) {
      return;
    }
    let selectionOptions: Array<DropdownItemProps> = new Array;

    selectionOptions.push(this.createOption(this.props.infra));
    this.selectOptions = selectionOptions;

    let sd = this.props.getSensor();
    // sd.targetId = this.props.infra.target.id;
    // sd.type = this.props.infra.infraType.name;
    sd.infra = this.props.infra;
    this.props.setSensor(sd);
    this.props.stepNext();
  }

  public createOption(infra: Infra): DropdownItemProps {
    let option = {
      key: infra.id,
      text: infra.infraType.name + '-' + infra.target.displayName,
      // value: infra.target.id,
      value: JSON.stringify(infra),
      // icon: 'check', // or close?
    };
    return option;
  }

  public defaultValue(): any {
    if (this.selectOptions !== undefined && this.selectOptions.length > 0) {
      return this.selectOptions[0].value;
    }
    return null;
  }

  public onChangeTarget(event: React.SyntheticEvent<HTMLElement>, data: DropdownProps): void {
    let sd = this.props.getSensor();
    // let infra: Infra = JSON.parse(String(data.value));
    // sd.targetId = infra.target.id;
    // sd.type = infra.infraType.name;
    sd.infra = JSON.parse(String(data.value));
    this.props.setSensor(sd);
  }

  public renderInfra(): JSX.Element {

    if (this.props.infraId === undefined) {
      this.convertInfraList();
    } else {
      this.convertInfra();
    }

    return (<Dropdown
      placeholder='Select Target' selection options={this.selectOptions}
      // defaultValue={this.defaultValue()}
      onChange={this.onChangeTarget.bind(this)} />);
  }

  public render(): JSX.Element {
    return (
      <Container fluid>
        {this.renderInfra()}
      </Container>
    );
  }
}
